hreports package
================

Submodules
----------

hreports\.cli module
--------------------

.. automodule:: hreports.cli
    :members:
    :undoc-members:
    :show-inheritance:

hreports\.config module
-----------------------

.. automodule:: hreports.config
    :members:
    :undoc-members:
    :show-inheritance:

hreports\.hreports module
-------------------------

.. automodule:: hreports.hreports
    :members:
    :undoc-members:
    :show-inheritance:

hreports\.template\_filters module
----------------------------------

.. automodule:: hreports.template_filters
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: hreports
    :members:
    :undoc-members:
    :show-inheritance:
